import sys
from PyQt5.QtWebEngineWidgets import QWebEngineView
from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QUrl

app = QApplication(sys.argv)
webView = QWebEngineView()

# Variant 1: Reasonably fast
webView.load(QUrl('file:////tmp/autosave_The_Holy_City-Timpani_page_001.svg'))

# Variant 2: Slow for small files, not working for big ones
## webView.setHtml('<svg>........')

webView.show()
sys.exit(app.exec_())


#!/usr/bin/env python
# -*- encoding: utf8 -*-
"""
Copyright 2015 Hippos Technical Systems BV.
(but borrows somme code from the painting/svgviewer example of PyQt v4.x)

@author: larry
"""

from PyQt4 import QtCore, QtGui
import fitz
from PIL import Image, ImageQt

class ImageView(QtGui.QMainWindow):
    def __init__(self):
        QtGui.QMainWindow.__init__(self)

        self.imageLabel = QtGui.QLabel()
        self.imageLabel.setBackgroundRole(QtGui.QPalette.Base)
        self.imageLabel.setScaledContents(True)

        self.scrollArea = QtGui.QScrollArea()
        self.scrollArea.setWidget(self.imageLabel)
        self.setCentralWidget(self.scrollArea)

        self.setWindowTitle("Image Viewer")
        self.resize(640, 480)


    def open(self, fileName):
        doc = fitz.open(fileName)
        page = doc[0]
        pix = page.getPixmap()
        #get data and display
        #pilimg = getMyPILImageDatFromCamera()
        #image = PILQT.ImageQt.ImageQt(pilimg)
        if 0:  # image.isNull():
            QtGui.QMessageBox.information(self, "Image Viewer","Cannot load %s." % fileName)
            return
        #self.imageLabel.setPixmap(QtGui.QPixmap.fromImage(image))
        img = Image.frombytes("RGBA", [pix.width, pix.height], pix.samples)
        qtimg = ImageQt.ImageQt(img)
        self.imageLabel.setPixmap(QtGui.QPixmap.fromImage(qtimg))
        self.imageLabel.adjustSize()


if __name__ == '__main__':

    import sys

    app = QtWidgets.QApplication(sys.argv)
    imageView = ImageView()
    imageView.open(*sys.argv[1:])
    imageView.show()
    sys.exit(app.exec_())


#!/usr/bin/env python3
"""
Copyright 2015 Hippos Technical Systems BV.
(but borrows somme code from the painting/svgviewer example of PyQt v4.x)

@author: larry
n.b. text_view.py is defunct... for now! just use normal stdout window! why not?  
"""

from .. import (dbg_print, QtWidgets, WithMenu)

class TextView(QtWidgets.QPlainTextEdit, WithMenu):

    menuTag = '&Text'

    def menuItems(self):
        return [
#                    ('Set &Font', 'F', self.changeMyFont,),
        ]

    def __init__(self):
        dbg_print ("TextView.__init__")
        QtWidgets.QPlainTextEdit.__init__(self)
        WithMenu.__init__(self)

    def showOutput(self, text_bytes):
        self.setPlainText(text_bytes)

    def showAtRowAndCol(self, row, col):
        pass  # for now!

    def locateXY(self, x, y):
        pass  # for now!



"""
MusicRaft
"""

#from distutils.core import setup
import sys, os, pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

linux_exec_dir = 'share/linux/bin/'
linux_exec_dir_here = os.path.join(HERE, linux_exec_dir)
linux_execs = [os.path.join(linux_exec_dir, one_exec)
               for one_exec in os.listdir(linux_exec_dir_here)]

# This call to setup() does all the work
setup(name = 'MusicRaft',
    version = '0.6.9',
    description='GUI for abcplus music notation.',
    long_description=README,
    long_description_content_type="text/markdown",
    url='https://gitlab.com/papahippo/MusicRaft',
    author = "Larry Myerscough",
    author_email='hippostech@gmail.com',
    packages=find_packages(),
    data_files = [(linux_exec_dir, linux_execs), ],
      scripts=['lin_musicraft.py', 'win_musicraft.py', 'share/linux/bin/xml2abc.py' ],
    license='LICENSE.txt',
    install_requires=[
        "mido == 1.1.14",
        #"pyqtgraph >= 0.10.0",
        "lxml",
        #"pyaudio",
        "numpy",
        #"pillow",
        "PySide2",

    ],
)
